==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/cs.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zadaný operátor není platný",
    "The given regular expression is invalid" : "Zadaný regulární výraz není platný",
    "The given file size is invalid" : "Zadaná velikost souboru není platná",
    "The given tag id is invalid" : "Zadaný identifikátor značky není platný",
    "The given IP range is invalid" : "Zadaný rozsah IP adres není platný",
    "The given IP range is not valid for IPv4" : "Zadaný rozsah IP adres není pro IPv4 platný",
    "The given IP range is not valid for IPv6" : "Zadaný rozsah IP adres není pro IPv6 platný",
    "The given time span is invalid" : "Zadaný časový rozsah není platný",
    "The given start time is invalid" : "Zadaný počáteční čas není platný",
    "The given end time is invalid" : "Zadaný koncový čas je neplatný",
    "The given group does not exist" : "Zadaná skupina neexistuje",
    "File" : "Soubor",
    "File created" : "Soubor vytvořen",
    "File updated" : "Soubor aktualizován",
    "File renamed" : "Soubor přejmenován",
    "File deleted" : "Soubor smazán",
    "File accessed" : "K souboru přistoupeno",
    "File copied" : "Soubor zkopírován",
    "Tag assigned" : "Štítek přiřazen",
    "Someone" : "Někdo",
    "%s created %s" : "%s vytvořeno %s",
    "%s modified %s" : "%s změněno %s",
    "%s deleted %s" : "%s smazáno %s",
    "%s accessed %s" : "%s přistoupeno k %s",
    "%s renamed %s" : "%s přejmenováno %s",
    "%s copied %s" : "%s zkopírováno %s",
    "%s assigned %s to %s" : "%s přiřazeno %s k %s",
    "Operation #%s does not exist" : "Operace č. %s neexistuje",
    "Entity %s does not exist" : "Entita %s neexistuje",
    "Entity %s is invalid" : "Entita %s není platná",
    "No events are chosen." : "Nejsou zvolené žádné události",
    "Entity %s has no event %s" : "Entita %s nemá událost %s",
    "Operation %s does not exist" : "Operace %s neexistuje",
    "Operation %s is invalid" : "Operace %s není platná",
    "At least one check needs to be provided" : "Je třeba poskytnou alespoň jednu kontrolu",
    "Invalid check provided" : "Zadána neplatná kontrola",
    "Check %s does not exist" : "Kontrola %s neexistuje",
    "Check %s is invalid" : "Kontrola %s je neplatná",
    "Check %s is not allowed with this entity" : "Zaškrtnutí %s není u této entity povoleno",
    "Check #%s does not exist" : "Kontrola č. %s neexistuje",
    "Check %s is invalid or does not exist" : "Kontrola %s není platná, nebo neexistuje",
    "Flow" : "Tok",
    "Nextcloud workflow engine" : "Nextcloud engine pro pracovní postupy",
    "Select a filter" : "Vybrat filtr",
    "Select a comparator" : "Vyberte porovnání",
    "Select a file type" : "Vybrat typ souboru",
    "e.g. httpd/unix-directory" : "např. httpd/unix-directory",
    "Images" : "Obrázky",
    "Office documents" : "Kancelářské dokumenty",
    "PDF documents" : "PDF dokumenty",
    "Custom mimetype" : "Uživatelsky určený mimetyp",
    "Select a tag" : "Vybrat štítek",
    "No results" : "Žádné výsledky",
    "%s (invisible)" : "%s (neviditelné)",
    "%s (restricted)" : "%s (omezeno)",
    "Please enter a valid time span" : "Zadejte platné časové rozmezí",
    "Select a request URL" : "Vyberte URL požadavku",
    "Predefined URLs" : "Předdefinované URL",
    "Files WebDAV" : "Soubory WebDAV",
    "Others" : "Ostatní",
    "Custom URL" : "Uživatelsky určená URL",
    "Select a user agent" : "Vyberte user agent",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Desktopový klient",
    "Thunderbird & Outlook addons" : "Doplňky pro Thunderbird a Outlook",
    "Custom user agent" : "Uživatelem určený user agent",
    "At least one event must be selected" : "Je třeba vybrat alespoň jednu událost",
    "Add new flow" : "Přidat nový tok",
    "When" : "Kdy",
    "and" : "a",
    "Cancel" : "Storno",
    "Delete" : "Smazat",
    "The configuration is invalid" : "Nastavení není platné",
    "Active" : "Aktivní",
    "Save" : "Uložit",
    "Available flows" : "Toky k dispozici",
    "For details on how to write your own flow, check out the development documentation." : "Podrobnosti o tom, jak vytvářet toky naleznete v dokumentaci pro vývojáře.",
    "More flows" : "Další toky",
    "Browse the app store" : "Procházet katalog aplikací",
    "Show less" : "Zobrazit méně",
    "Show more" : "Zobrazit více",
    "Configured flows" : "Nastavené toky",
    "Your flows" : "Vaše toky",
    "matches" : "odpovídá",
    "does not match" : "neodpovídá",
    "is" : "je",
    "is not" : "není",
    "File name" : "Název souboru",
    "File MIME type" : "MIME typ souboru",
    "File size (upload)" : "Velikost souboru (nahráno)",
    "less" : "menší",
    "less or equals" : "menší nebo rovno",
    "greater or equals" : "větší nebo rovno",
    "greater" : "větší",
    "Request remote address" : "Vzdálená adresa požadavku",
    "matches IPv4" : "odpovídá IPv4",
    "does not match IPv4" : "neodpovídá IPv4",
    "matches IPv6" : "odpovídá IPv6",
    "does not match IPv6" : "neodpovídá IPv6",
    "File system tag" : "Štítek souborového systému",
    "is tagged with" : "je označeno jako",
    "is not tagged with" : "není označeno",
    "Request URL" : "URL požadavku",
    "Request time" : "Čas požadavku",
    "between" : "mezi",
    "not between" : "není mezi",
    "Request user agent" : "User agent požadavku",
    "User group membership" : "Členství ve skupinách uživatelů",
    "is member of" : "je členem",
    "is not member of" : "není členem",
    "Short rule description" : "Stručný popis pravidla",
    "Add rule" : "Přidat pravidlo",
    "Reset" : "Obnovit",
    "Saving…" : "Ukládání…",
    "Group list is empty" : "Seznam skupin je prázdný",
    "Unable to retrieve the group list" : "Nedaří se získat seznam skupin",
    "Saved" : "Uloženo",
    "Saving failed:" : "Ukládání se nezdařilo:",
    "Add rule group" : "Přidat skupinu pravidel",
    "Example: {placeholder}" : "Příklad: {placeholder}",
    "Select tag…" : "Vybrat štítek…",
    "Start" : "Začátek",
    "End" : "Konec",
    "Select timezone…" : "Vybrat časové pásmo…",
    "Sync clients" : "Synchronizační klienti",
    "Tag management" : "Správa štítků",
    "Files workflow engine" : "Engine práce se soubory",
    "Open documentation" : "Otevřít dokumentaci",
    "Loading…" : "Načítání…"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-21.0.1-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/cs.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zadaný operátor není platný",
    "The given regular expression is invalid" : "Zadaný regulární výraz není platný",
    "The given file size is invalid" : "Zadaná velikost souboru není platná",
    "The given tag id is invalid" : "Zadaný identifikátor značky není platný",
    "The given IP range is invalid" : "Zadaný rozsah IP adres není platný",
    "The given IP range is not valid for IPv4" : "Zadaný rozsah IP adres není pro IPv4 platný",
    "The given IP range is not valid for IPv6" : "Zadaný rozsah IP adres není pro IPv6 platný",
    "The given time span is invalid" : "Zadaný časový rozsah není platný",
    "The given start time is invalid" : "Zadaný počáteční čas není platný",
    "The given end time is invalid" : "Zadaný koncový čas není platný",
    "The given group does not exist" : "Zadaná skupina neexistuje",
    "File" : "Soubor",
    "File created" : "Soubor vytvořen",
    "File updated" : "Soubor aktualizován",
    "File renamed" : "Soubor přejmenován",
    "File deleted" : "Soubor smazán",
    "File accessed" : "K souboru přistoupeno",
    "File copied" : "Soubor zkopírován",
    "Tag assigned" : "Štítek přiřazen",
    "Someone" : "Někdo",
    "%s created %s" : "%s vytvořeno %s",
    "%s modified %s" : "%s změněno %s",
    "%s deleted %s" : "%s smazáno %s",
    "%s accessed %s" : "%s přistoupeno k %s",
    "%s renamed %s" : "%s přejmenováno %s",
    "%s copied %s" : "%s zkopírováno %s",
    "%s assigned %s to %s" : "%s přiřazeno %s k %s",
    "Operation #%s does not exist" : "Operace č. %s neexistuje",
    "Entity %s does not exist" : "Entita %s neexistuje",
    "Entity %s is invalid" : "Entita %s není platná",
    "No events are chosen." : "Nejsou zvolené žádné události",
    "Entity %s has no event %s" : "Entita %s nemá žádnou událost %s",
    "Operation %s does not exist" : "Operace %s neexistuje",
    "Operation %s is invalid" : "Operace %s není platná",
    "At least one check needs to be provided" : "Je třeba poskytnou alespoň jednu kontrolu",
    "The provided operation data is too long" : "Data zadané operace jsou příliš objemná",
    "Invalid check provided" : "Zadána neplatná kontrola",
    "Check %s does not exist" : "Kontrola %s neexistuje",
    "Check %s is invalid" : "Kontrola %s není platná",
    "Check %s is not allowed with this entity" : "Zaškrtnutí %s není u této entity povoleno",
    "The provided check value is too long" : "Zadaná hodnota kontroly je příliš dlouhá",
    "Check #%s does not exist" : "Kontrola č. %s neexistuje",
    "Check %s is invalid or does not exist" : "Kontrola %s není platná, nebo neexistuje",
    "Flow" : "Tok",
    "Nextcloud workflow engine" : "Nextcloud engine pro pracovní postupy",
    "Select a filter" : "Vybrat filtr",
    "Select a comparator" : "Vyberte porovnání",
    "Select a file type" : "Vybrat typ souboru",
    "e.g. httpd/unix-directory" : "např. httpd/unix-directory",
    "Folder" : "Složka",
    "Images" : "Obrázky",
    "Office documents" : "Kancelářské dokumenty",
    "PDF documents" : "PDF dokumenty",
    "Custom mimetype" : "Uživatelsky určený mimetyp",
    "Select a tag" : "Vybrat štítek",
    "No results" : "Žádné výsledky",
    "%s (invisible)" : "%s (neviditelné)",
    "%s (restricted)" : "%s (omezeno)",
    "Please enter a valid time span" : "Zadejte platné časové rozmezí",
    "Select a request URL" : "Vyberte URL požadavku",
    "Predefined URLs" : "Předdefinované URL",
    "Files WebDAV" : "Soubory WebDAV",
    "Others" : "Ostatní",
    "Custom URL" : "Uživatelsky určená URL",
    "Select a user agent" : "Vyberte user agent",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Klient pro počítač",
    "Thunderbird & Outlook addons" : "Doplňky pro Thunderbird a Outlook",
    "Custom user agent" : "Uživatelem určený user agent",
    "At least one event must be selected" : "Je třeba vybrat alespoň jednu událost",
    "Add new flow" : "Přidat nový tok",
    "When" : "Kdy",
    "and" : "a",
    "Cancel" : "Storno",
    "Delete" : "Smazat",
    "The configuration is invalid" : "Nastavení není platné",
    "Active" : "Aktivní",
    "Save" : "Uložit",
    "Available flows" : "Toky k dispozici",
    "For details on how to write your own flow, check out the development documentation." : "Podrobnosti o tom, jak vytvářet toky naleznete v dokumentaci pro vývojáře.",
    "More flows" : "Další toky",
    "Browse the app store" : "Procházet katalog aplikací",
    "Show less" : "Zobrazit méně",
    "Show more" : "Zobrazit více",
    "Configured flows" : "Nastavené toky",
    "Your flows" : "Vaše toky",
    "matches" : "odpovídá",
    "does not match" : "neodpovídá",
    "is" : "je",
    "is not" : "není",
    "File name" : "Název souboru",
    "File MIME type" : "MIME typ souboru",
    "File size (upload)" : "Velikost souboru (nahráno)",
    "less" : "menší",
    "less or equals" : "menší nebo rovno",
    "greater or equals" : "větší nebo rovno",
    "greater" : "větší",
    "Request remote address" : "Vzdálená adresa požadavku",
    "matches IPv4" : "odpovídá IPv4",
    "does not match IPv4" : "neodpovídá IPv4",
    "matches IPv6" : "odpovídá IPv6",
    "does not match IPv6" : "neodpovídá IPv6",
    "File system tag" : "Štítek souborového systému",
    "is tagged with" : "je označeno jako",
    "is not tagged with" : "není označeno",
    "Request URL" : "URL požadavku",
    "Request time" : "Čas požadavku",
    "between" : "mezi",
    "not between" : "není mezi",
    "Request user agent" : "User agent požadavku",
    "User group membership" : "Členství ve skupinách uživatelů",
    "is member of" : "je členem",
    "is not member of" : "není členem"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
